@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 =begin rdoc
-=Recerve - 指定時間にブロックを実行
+=Reserver - 指定時間にブロックを実行
 指定された時間に一度だけブロックを実行します。調整できる単位は秒です。
 アプリケーションが終了するなど、予期せぬ自体が起こると実行されないことがあります。
 =end
