@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 require 'gtk2'
-require File.expand_path(File.join(File.dirname(__FILE__), '..', 'utils'))
+require_relative '../utils'
 miquire :core, 'message', 'skin'
 miquire :mui, 'mtk'
 miquire :mui, 'extension'
