@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-require File.expand_path File.join(File.dirname(__FILE__), 'conditions')
+require_relative 'conditions'
 
 Plugin.create :command do
 
