@@ -16,15 +16,8 @@ module Plugin::Photo
       case uri
       when self
         uri
-      when URI, Addressable::URI, Retriever::URI
+      when URI, Addressable::URI, Retriever::URI, String
         photos[uri.to_s.hash] ||= new(perma_link: uri)
-      when String
-        if uri.start_with?('http')
-          photos[uri.hash] ||= new(perma_link: uri)
-        elsif uri.start_with?('/')
-          uri = Retriever::URI.new(scheme: 'file', path: uri)
-          photos[uri.hash] ||= new(perma_link: uri)
-        end
       end
     end
 
