@@ -2,6 +2,8 @@
 
 module Plugin::Search
   class Search < Retriever::Model
+    extend Memoist
+
     register :twitter_search, name: Plugin[:search]._('Twitter検索')
 
     field.string :query, required: true
@@ -17,6 +19,10 @@ module Plugin::Search
       new(query: CGI.unescape(query))
     end
 
+    def title
+      Plugin[:search]._("「%{query}」でツイート検索") % {query: query}
+    end
+
     memoize def perma_link
       Retriever::URI.new("https://twitter.com/search?q=#{CGI.escape(self.query)}")
     end
