@@ -144,7 +144,7 @@ class User < Retriever::Model
   alias to_user user
 
   def marshal_dump
-    raise RuntimeError, 'User cannot marshalize'
+    raise RuntimeError, 'User cannot marshal'
   end
 
   class UserMemory < Retriever::Model::Memory
