@@ -11,9 +11,7 @@ This software is released under the MIT License.
 http://opensource.org/licenses/mit-license.php
 
 =end
-mikutter_directory = File.expand_path(File.dirname(__FILE__))
-
-require File.expand_path(File.join(mikutter_directory, 'core/boot/option'))
+require_relative 'core/boot/option'
 Mopt.parse exec_command: true
 
 if !ENV['DISABLE_BUNDLER_SETUP'] || ['', '0'].include?(ENV['DISABLE_BUNDLER_SETUP'].to_s)
@@ -33,7 +31,7 @@ require 'webrick'
 require 'thread'
 require 'fileutils'
 
-require File.expand_path(File.join(mikutter_directory, 'core/utils'))
+require_relative 'core/utils'
 
 miquire :boot, 'check_config_permission', 'mainloop', 'delayer'
 miquire :core, 'service', 'environment'
